@@ -24,7 +24,7 @@ predict_survival.model_fit <- function(object,
   check_spec_pred_type(object, "survival")
 
   if (inherits(object$fit, "try-error")) {
-    rlang::warn("Model fit failed; cannot make predictions.")
+    cli::cli_warn("Model fit failed; cannot make predictions.")
     return(NULL)
   }
 
