@@ -1,6 +1,6 @@
 #' Determine required packages for a model
 #'
-#' @param x A model specification or fit.
+#' @param x A [model specification][model_spec] or [fit][model_fit].
 #' @param infra Should parsnip itself be included in the result?
 #' @param ... Not used.
 #' @return A character vector
@@ -24,14 +24,16 @@
 #' @export
 required_pkgs.model_spec <- function(x, infra = TRUE, ...) {
   if (is.null(x$engine)) {
-    rlang::abort("Please set an engine.")
+    cli::cli_abort("Please set an engine.")
   }
+  check_bool(infra)
   get_pkgs(x, infra)
 }
 
 #' @export
 #' @rdname required_pkgs.model_spec
 required_pkgs.model_fit <- function(x, infra = TRUE, ...) {
+  check_bool(infra)
   get_pkgs(x$spec, infra)
 }
 
