@@ -1,10 +1,10 @@
 #' Resolve a Model Specification for a Computational Engine
 #'
-#' `translate()` will translate a model specification into a code
+#' `translate()` will translate a [model specification][model_spec] into a code
 #'  object that is specific to a particular engine (e.g. R package).
 #'  It translates generic parameters to their counterparts.
 #'
-#' @param x A model specification.
+#' @param x A [model specification][model_spec].
 #' @param engine The computational engine for the model (see `?set_engine`).
 #' @param ... Not currently used.
 #' @details
@@ -20,7 +20,7 @@
 #'  the model fitting function/engine.
 #'
 #' This function can be useful when you need to understand how
-#'  `parsnip` goes from a generic model specific to a model fitting
+#'  parsnip goes from a generic model specific to a model fitting
 #'  function.
 #'
 #' **Note**: this function is used internally and users should only use it
@@ -52,14 +52,15 @@ translate <- function(x, ...)
 #' @export translate.default
 translate.default <- function(x, engine = x$engine, ...) {
   check_empty_ellipse(...)
-  if (is.null(engine))
-    rlang::abort("Please set an engine.")
+  if (is.null(engine)) {
+    cli::cli_abort("Please set an engine.")
+  }
 
   mod_name <- specific_model(x)
 
   x$engine <- engine
   if (x$mode == "unknown") {
-    rlang::abort("Model code depends on the mode; please specify one.")
+    cli::cli_abort("Model code depends on the mode; please specify one.")
   }
 
   check_spec_mode_engine_val(class(x)[1], x$engine, x$mode)
@@ -175,6 +176,7 @@ add_methods <- function(x, engine) {
 #' or in a list that can facilitate renaming grid objects?
 #' @return A tibble with columns `user`, `parsnip`, and `engine`, or a list
 #' with named character vectors `user_to_parsnip` and `parsnip_to_engine`.
+#' @keywords internal
 #' @examplesIf !parsnip:::is_cran_check()
 #' mod <-
 #'  linear_reg(penalty = tune("regularization"), mixture = tune()) %>%
@@ -196,7 +198,7 @@ add_methods <- function(x, engine) {
 #' @export
 .model_param_name_key <- function(object, as_tibble = TRUE) {
   if (!inherits(object, c("model_spec", "workflow"))) {
-    rlang::abort("'object' should be a model specification or workflow.")
+    cli::cli_abort("{.arg object} should be a model specification or workflow.")
   }
   if (inherits(object, "workflow")) {
     object <- hardhat::extract_spec_parsnip(object)
